==> jc-1.4.0.tar.gz: jasmin/CUP__24parser__24actions.h <==
// class jasmin.CUP$parser$actions

// class file dependencies
// @dep_class e4e5c79184c7f108 jasmin_CUP__24parser__24actions
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jasmin_CUP__24parser__24actions_H_
#define _JC_jasmin_CUP__24parser__24actions_H_

// Forward structure declarations
struct _jc_jasmin_ClassFile$object;
struct _jc_jasmin_Scanner$object;
struct _jc_jasmin_parser$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_Stack$object;
struct _jc_java__5fcup_runtime_Symbol$object;
struct _jc_java__5fcup_runtime_lr__5fparser$object;

// Typedefs
typedef struct _jc_jasmin_CUP__24parser__24actions$sub_refs	_jc_jasmin_CUP__24parser__24actions$sub_refs;
typedef struct _jc_jasmin_CUP__24parser__24actions$sub_nonrefs	_jc_jasmin_CUP__24parser__24actions$sub_nonrefs;
typedef struct _jc_jasmin_CUP__24parser__24actions$refs	_jc_jasmin_CUP__24parser__24actions$refs;
typedef struct _jc_jasmin_CUP__24parser__24actions$nonrefs	_jc_jasmin_CUP__24parser__24actions$nonrefs;
typedef struct _jc_jasmin_CUP__24parser__24actions$object	_jc_jasmin_CUP__24parser__24actions$object;

typedef const struct _jc_jasmin_CUP__24parser__24actions$vmethods	_jc_jasmin_CUP__24parser__24actions$vmethods;
typedef const struct _jc_jasmin_CUP__24parser__24actions$vtable	_jc_jasmin_CUP__24parser__24actions$vtable;
typedef const struct _jc_jasmin_CUP__24parser__24actions$vtype	_jc_jasmin_CUP__24parser__24actions$vtype;

// Constructors
extern void _jc_jasmin_CUP__24parser__24actions$method$_init$1a6575d034a1fb4f(_jc_env *, struct _jc_jasmin_CUP__24parser__24actions$object *, struct _jc_jasmin_parser$object *);

// Virtual methods
extern struct _jc_java__5fcup_runtime_Symbol$object *_jc_jasmin_CUP__24parser__24actions$method$CUP__24parser__24do__5faction$9fbf6b0c92c67312(_jc_env *, struct _jc_jasmin_CUP__24parser__24actions$object *, jint, struct _jc_java__5fcup_runtime_lr__5fparser$object *, struct _jc_java_util_Stack$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_jasmin_CUP__24parser__24actions$method_info$CUP__24parser__24do__5faction$9fbf6b0c92c67312;

// Virtual methods structure
struct _jc_jasmin_CUP__24parser__24actions$vmethods {
	struct _jc_java__5fcup_runtime_Symbol$object	*(*CUP__24parser__24do__5faction$9fbf6b0c92c67312)(_jc_env *, struct _jc_jasmin_CUP__24parser__24actions$object *, jint, struct _jc_java__5fcup_runtime_lr__5fparser$object *, struct _jc_java_util_Stack$object *, jint);
};

// Vtable
struct _jc_jasmin_CUP__24parser__24actions$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jasmin_CUP__24parser__24actions$vmethods	jasmin_CUP__24parser__24actions;
};

// Vtype
struct _jc_jasmin_CUP__24parser__24actions$vtype {
	_jc_type			type;
	_jc_jasmin_CUP__24parser__24actions$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jasmin_CUP__24parser__24actions$sub_refs {
	struct _jc_jasmin_Scanner$object	*scanner;
	struct _jc_jasmin_ClassFile$object	*classFile;
	struct _jc_jasmin_parser$object	*parser;
};

// Reference instance fields (object)
struct _jc_jasmin_CUP__24parser__24actions$refs {
    _jc_jasmin_CUP__24parser__24actions$sub_refs	jasmin_CUP__24parser__24actions;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jasmin_CUP__24parser__24actions$sub_nonrefs {
	jshort	access__5fval;
};

// Non-reference instance fields (object)
struct _jc_jasmin_CUP__24parser__24actions$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jasmin_CUP__24parser__24actions$sub_nonrefs	jasmin_CUP__24parser__24actions;
};

// Object instance structure
struct _jc_jasmin_CUP__24parser__24actions$object {
	_jc_jasmin_CUP__24parser__24actions$refs	refs[0];
	_jc_word		lockword;
	_jc_jasmin_CUP__24parser__24actions$vtype	*vtype;
	_jc_jasmin_CUP__24parser__24actions$nonrefs	nonrefs;
};

// Type structure
extern _jc_jasmin_CUP__24parser__24actions$vtype _jc_jasmin_CUP__24parser__24actions$type;

// Array types class info structures
_JC_DECL_ARRAYS(jasmin_CUP__24parser__24actions, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jasmin_CUP__24parser__24actions$class_object;

#endif	/* _JC_jasmin_CUP__24parser__24actions_H_ */

==> jc-1.4.6.tar.gz: jasmin/CUP__24parser__24actions.h <==
// class jasmin.CUP$parser$actions

// class file dependencies
// @dep_class e4e5c79184c7f108 jasmin_CUP__24parser__24actions
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jasmin_CUP__24parser__24actions_H_
#define _JC_jasmin_CUP__24parser__24actions_H_

// Forward structure declarations
struct _jc_jasmin_ClassFile$object;
struct _jc_jasmin_Scanner$object;
struct _jc_jasmin_parser$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_Stack$object;
struct _jc_java__5fcup_runtime_Symbol$object;
struct _jc_java__5fcup_runtime_lr__5fparser$object;

// Typedefs
typedef struct _jc_jasmin_CUP__24parser__24actions$sub_refs	_jc_jasmin_CUP__24parser__24actions$sub_refs;
typedef struct _jc_jasmin_CUP__24parser__24actions$sub_nonrefs	_jc_jasmin_CUP__24parser__24actions$sub_nonrefs;
typedef struct _jc_jasmin_CUP__24parser__24actions$refs	_jc_jasmin_CUP__24parser__24actions$refs;
typedef struct _jc_jasmin_CUP__24parser__24actions$nonrefs	_jc_jasmin_CUP__24parser__24actions$nonrefs;
typedef struct _jc_jasmin_CUP__24parser__24actions$object	_jc_jasmin_CUP__24parser__24actions$object;

typedef const struct _jc_jasmin_CUP__24parser__24actions$vmethods	_jc_jasmin_CUP__24parser__24actions$vmethods;
typedef const struct _jc_jasmin_CUP__24parser__24actions$vtable	_jc_jasmin_CUP__24parser__24actions$vtable;
typedef const struct _jc_jasmin_CUP__24parser__24actions$vtype	_jc_jasmin_CUP__24parser__24actions$vtype;

// Constructors
extern void _jc_jasmin_CUP__24parser__24actions$method$_init$1a6575d034a1fb4f(_jc_env *, struct _jc_jasmin_CUP__24parser__24actions$object *, struct _jc_jasmin_parser$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java__5fcup_runtime_Symbol$object *_jc_jasmin_CUP__24parser__24actions$method$CUP__24parser__24do__5faction$9fbf6b0c92c67312(_jc_env *, struct _jc_jasmin_CUP__24parser__24actions$object *, jint, struct _jc_java__5fcup_runtime_lr__5fparser$object *, struct _jc_java_util_Stack$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_jasmin_CUP__24parser__24actions$method_info$CUP__24parser__24do__5faction$9fbf6b0c92c67312;

// Virtual methods structure
struct _jc_jasmin_CUP__24parser__24actions$vmethods {
	struct _jc_java__5fcup_runtime_Symbol$object	*(*CUP__24parser__24do__5faction$9fbf6b0c92c67312)(_jc_env *, struct _jc_jasmin_CUP__24parser__24actions$object *, jint, struct _jc_java__5fcup_runtime_lr__5fparser$object *, struct _jc_java_util_Stack$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_jasmin_CUP__24parser__24actions$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jasmin_CUP__24parser__24actions$vmethods	jasmin_CUP__24parser__24actions;
};

// Vtype
struct _jc_jasmin_CUP__24parser__24actions$vtype {
	_jc_type			type;
	_jc_jasmin_CUP__24parser__24actions$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jasmin_CUP__24parser__24actions$sub_refs {
	struct _jc_jasmin_Scanner$object	*scanner;
	struct _jc_jasmin_ClassFile$object	*classFile;
	struct _jc_jasmin_parser$object	*parser;
};

// Reference instance fields (object)
struct _jc_jasmin_CUP__24parser__24actions$refs {
    _jc_jasmin_CUP__24parser__24actions$sub_refs	jasmin_CUP__24parser__24actions;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jasmin_CUP__24parser__24actions$sub_nonrefs {
	jshort	access__5fval;
};

// Non-reference instance fields (object)
struct _jc_jasmin_CUP__24parser__24actions$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jasmin_CUP__24parser__24actions$sub_nonrefs	jasmin_CUP__24parser__24actions;
};

// Object instance structure
struct _jc_jasmin_CUP__24parser__24actions$object {
	_jc_jasmin_CUP__24parser__24actions$refs	refs[0];
	_jc_word		lockword;
	_jc_jasmin_CUP__24parser__24actions$vtype	*vtype;
	_jc_jasmin_CUP__24parser__24actions$nonrefs	nonrefs;
};

// Type structure
extern _jc_jasmin_CUP__24parser__24actions$vtype _jc_jasmin_CUP__24parser__24actions$type;

// Array types class info structures
_JC_DECL_ARRAYS(jasmin_CUP__24parser__24actions, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jasmin_CUP__24parser__24actions$class_object;

#endif	/* _JC_jasmin_CUP__24parser__24actions_H_ */
